import React, { forwardRef } from 'react';
import { Dialog, DialogContentPrimitive, DialogDescription, DialogFooter, DialogHeader, DialogOverlay, DialogTrigger, useCloseDialog, } from './dialog.js';
import { Container, DefaultProperties } from '@react-three/uikit';
import { borderRadius, colors } from './theme.js';
export const AlertDialogOverlay = DialogOverlay;
export const AlertDialog = Dialog;
export const AlertDialogTrigger = DialogTrigger;
export const AlertDialogContent = forwardRef(({ onClick, sm, ...props }, ref) => {
    const close = useCloseDialog();
    return (React.createElement(DialogContentPrimitive, null,
        React.createElement(DialogOverlay, { onClick: (e) => {
                close();
                e.stopPropagation();
            }, alignItems: "center", justifyContent: "center" },
            React.createElement(Container, { onClick: (e) => {
                    e.stopPropagation();
                    onClick?.(e);
                }, positionType: "relative", flexDirection: "column", maxWidth: 512, width: "100%", gap: 16, borderWidth: 1, backgroundColor: colors.background, padding: 24, sm: { borderRadius: borderRadius.lg, ...sm }, ref: ref, ...props }))));
});
export const AlertDialogHeader = DialogHeader;
export const AlertDialogFooter = DialogFooter;
export function AlertDialogTitle(props) {
    return React.createElement(DefaultProperties, { fontSize: 18, lineHeight: 28, fontWeight: "semi-bold", ...props });
}
export const AlertDialogDescription = DialogDescription;
export const AlertDialogAction = forwardRef(({ children, onClick, ...props }, ref) => {
    const close = useCloseDialog();
    return (React.createElement(Container, { borderRadius: borderRadius.md, height: 40, paddingX: 16, paddingY: 8, alignItems: "center", justifyContent: "center", cursor: "pointer", flexDirection: "row", backgroundColor: colors.primary, onClick: (e) => {
            e.stopPropagation();
            close();
            onClick?.(e);
        }, hover: {
            backgroundOpacity: 0.9,
        }, ref: ref, ...props },
        React.createElement(DefaultProperties, null,
            React.createElement(DefaultProperties, { fontSize: 14, lineHeight: 20, fontWeight: "medium", wordBreak: "keep-all", color: colors.primaryForeground }, children))));
});
export const AlertDialogCancel = forwardRef(({ children, onClick, ...props }, ref) => {
    const close = useCloseDialog();
    return (React.createElement(Container, { borderRadius: borderRadius.md, height: 40, paddingX: 16, paddingY: 8, alignItems: "center", justifyContent: "center", cursor: "pointer", flexDirection: "row", borderWidth: 1, borderColor: colors.input, backgroundColor: colors.background, onClick: (e) => {
            e.stopPropagation();
            close();
            onClick?.(e);
        }, hover: {
            backgroundColor: colors.accent,
        }, ref: ref, ...props },
        React.createElement(DefaultProperties, { fontSize: 14, lineHeight: 20, fontWeight: "medium", wordBreak: "keep-all" }, children)));
});
