import { Container, DefaultProperties } from '@react-three/uikit';
import React, { createContext, forwardRef, useContext, useEffect, useRef, useState, } from 'react';
import { borderRadius, colors } from './theme.js';
const TooltipContext = createContext(null);
export const Tooltip = forwardRef(({ children, ...props }, ref) => {
    const [open, setOpen] = useState(false);
    const timeoutRef = useRef(undefined);
    useEffect(() => () => {
        if (timeoutRef.current == null) {
            return;
        }
        clearTimeout(timeoutRef.current);
    }, []);
    return (React.createElement(Container, { onPointerOver: () => {
            if (timeoutRef.current != null) {
                return;
            }
            timeoutRef.current = setTimeout(() => {
                timeoutRef.current = undefined;
                setOpen(true);
            }, 1000);
        }, onPointerOut: () => {
            if (timeoutRef.current != null) {
                clearTimeout(timeoutRef.current);
                timeoutRef.current = undefined;
                return;
            }
            setOpen(false);
        }, positionType: "relative", flexDirection: "column", alignItems: "center", ref: ref, ...props },
        React.createElement(TooltipContext.Provider, { value: open }, children)));
});
export const TooltipTrigger = forwardRef((props, ref) => {
    return React.createElement(Container, { alignSelf: "stretch", ref: ref, ...props });
});
export const TooltipContent = forwardRef(({ children, sideOffset = 4, ...props }, ref) => {
    const open = useContext(TooltipContext);
    if (!open) {
        return null;
    }
    return (React.createElement(Container, { positionType: "absolute", positionBottom: "100%", marginBottom: sideOffset, zIndexOffset: 50, overflow: "hidden", borderRadius: borderRadius.md, borderWidth: 1, backgroundColor: colors.popover, paddingX: 12, paddingY: 6, ref: ref, ...props },
        React.createElement(DefaultProperties, { wordBreak: "keep-all", fontSize: 14, lineHeight: 20, color: colors.popoverForeground }, children)));
});
